==> kubernetes-model-coordination-6.6.2-sources.jar: io/fabric8/kubernetes/api/model/coordination/v1/LeaseSpecFluent.java <==
package io.fabric8.kubernetes.api.model.coordination.v1;

import java.lang.Integer;
import java.time.ZonedDateTime;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface LeaseSpecFluent<A extends LeaseSpecFluent<A>> extends Fluent<A>{
  public ZonedDateTime getAcquireTime();
  public A withAcquireTime(ZonedDateTime acquireTime);
  public Boolean hasAcquireTime();
  public String getHolderIdentity();
  public A withHolderIdentity(String holderIdentity);
  public Boolean hasHolderIdentity();
  public Integer getLeaseDurationSeconds();
  public A withLeaseDurationSeconds(Integer leaseDurationSeconds);
  public Boolean hasLeaseDurationSeconds();
  public Integer getLeaseTransitions();
  public A withLeaseTransitions(Integer leaseTransitions);
  public Boolean hasLeaseTransitions();
  public ZonedDateTime getRenewTime();
  public A withRenewTime(ZonedDateTime renewTime);
  public Boolean hasRenewTime();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}

==> kubernetes-model-coordination-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/coordination/v1/LeaseSpecFluent.java <==
package io.fabric8.kubernetes.api.model.coordination.v1;

import java.lang.Integer;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.time.ZonedDateTime;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface LeaseSpecFluent<A extends LeaseSpecFluent<A>> extends Fluent<A>{
  public ZonedDateTime getAcquireTime();
  public A withAcquireTime(ZonedDateTime acquireTime);
  public Boolean hasAcquireTime();
  public String getHolderIdentity();
  public A withHolderIdentity(String holderIdentity);
  public Boolean hasHolderIdentity();
  public Integer getLeaseDurationSeconds();
  public A withLeaseDurationSeconds(Integer leaseDurationSeconds);
  public Boolean hasLeaseDurationSeconds();
  public Integer getLeaseTransitions();
  public A withLeaseTransitions(Integer leaseTransitions);
  public Boolean hasLeaseTransitions();
  public ZonedDateTime getRenewTime();
  public A withRenewTime(ZonedDateTime renewTime);
  public Boolean hasRenewTime();
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  
}
